@@ -1,6 +1,7 @@
 import mwutils
 from mwutils.logs import Logger, mili_time
 from mwutils.sys_stat import SystemStats
+
 import os
 import requests
 import warnings
@@ -9,9 +10,16 @@ import time
 import traceback
 import signal
 import json
+import boto3
+import botocore
+import time
+import logging
+
 import numpy as np
 from os import path, getpid
 from random import randrange
+from botocore.exceptions import ClientError
+
 
 _STEP = 'step'
 _EPOCH = 'epoch'
@@ -95,7 +103,7 @@ class CustomLogger(Logger):
 
 
 class Run():
-    def __init__(self, name="", user_id="", lab_id="", org_id="", flush_interval_seconds=5,
+    def __init__(self, name="", user_id="", lab_id="", org_id="", token="", flush_interval_seconds=5,
                  sys_stat_sample_size=1, sys_stat_sample_interval=2, local_path='', write_logs_to_local=False,
                  remote_path='', buffer_all_logs=False):
         if name == '':
@@ -109,6 +117,7 @@ class Run():
         config_user_id = None
         config_lab_id = None
         config_org_id = None
+        config_token = None
         if os.path.exists(_path):
             f = open(_path)
             _data = json.load(f)
@@ -118,12 +127,15 @@ class Run():
             config_user_id = _data['website']['user']['_id']
             config_lab_id = _data['website']['lab']['_id']
             config_org_id = _data['website']['org']['_id']
+            config_token = _data['website']['token']
         run_names[name] = self
         self._loggers = {}
         self.custom_loggers = {}
         env_user_id = os.getenv("ENV_USER_ID")
         env_lab_id = os.getenv("ENV_LAB_ID")
         env_org_id = os.getenv("ENV_ORG_ID")
+        env_token = os.getenv("ENV_TOKEN")
+
         if config_user_id:
             self.user_id = config_user_id
         elif env_user_id:
@@ -136,6 +148,7 @@ class Run():
             self.lab_id = env_lab_id
         else:
             self.lab_id = lab_id
+
         if config_org_id:
             self.org_id = config_org_id
         elif env_org_id:
@@ -143,6 +156,13 @@ class Run():
         else:
             self.org_id = org_id
 
+        if config_token:
+            self.user_token = config_token
+        elif env_token:
+            self.user_token = config_token
+        else:
+            self.user_token = token
+
         if remote_path:
             self.remote_path = remote_path
         elif _remote_path:
@@ -347,7 +367,7 @@ class Run():
             import time
             epoch_time = int(time.time())
             os.mkdir(str(epoch_time))
-            _path = str(epoch_time) + '/project'
+            _path = str(epoch_time)
             os.mkdir(_path)
             if target == None:
                 print('no model specified, skipping')
@@ -380,19 +400,38 @@ class Run():
                     except:
                         print('model cannot be saved, please check format')
 
-            import os
-            import zipfile
+            path_artifact = '/api/dataset-upload-token?subType=artifact'
+            endpoint_get_token = self.remote_path.replace(
+                '/api/runs', path_artifact) + '&token=' + self.token
+            oss_config = requests.get(endpoint_get_token)
+            AK = oss_config['accessKeyId']
+            SK = oss_config['secretAccessKey']
+            region = oss_config['region']
+            Session = oss_config['sessionToken']
+            bucket = oss_config['bucket']
 
-            def zipdir(path, ziph):
-                # ziph is zipfile handle
-                for root, dirs, files in os.walk(path):
-                    for file in files:
-                        ziph.write(os.path.join(root, file),
-                                   os.path.relpath(os.path.join(root, file),
-                                                   os.path.join(path, '..')))
-            zip_name = str(epoch_time) + '.zip'
-            with zipfile.ZipFile(zip_name, 'w', zipfile.ZIP_DEFLATED) as zipf:
-                zipdir(_path, zipf)
+            epoch_time = int(time.time())
+
+            s3_client = boto3.client('s3',
+                                     region_name=region,
+                                     aws_access_key_id=AK,
+                                     aws_secret_access_key=SK,
+                                     aws_session_token=Session
+                                     )
+
+            upload_dir = '~/project/' + _path
+            for subdir, dirs, files in os.walk(upload_dir):
+                for file in files:
+                    fullpath = os.path.join(subdir, file)
+                    try:
+                        object_name = oss_config['prefixToSave'] + \
+                            str(epoch_time) + '/' + file
+                        print('uploading file: ', fullpath)
+                        response = s3_client.upload_file(
+                            fullpath, bucket, object_name)
+                    except ClientError as e:
+                        logging.error(e)
+                        print('Error uploading file ', file)
 
         if self.remote_path:
             tp = int(time.time())
